
Changelog
=========

0.0.0 (2021-09-27)
------------------

* First release on PyPI.

0.1.0 (2021-10-01)
------------------

* Added Modifiers: Boolean, Array, Solidify and Bevel
* Added fromPyData()
* Improved documentation
* Added example files
* Added dark theme to docs

0.1.1 (2021-10-01)
------------------

* Hotfix of missing dependencies in package

0.1.2 (2021-10-01)
------------------

* Hotfix of export/import API

0.2.0 (2021-10-03)
------------------

* Added materials shortcuts
* Updated documentation
* Bpy is no longer automatically installed
* Bpy can be now installed via PyR3.install_bpy script